Module binop

Module binop 

Binary operator aggregate channel implementation.

A channel that reduces multiple writes using a binary operator function.

Structs

BinaryOperatorAggregate
A channel that reduces values using a binary operator.

Functions

max_channel
Create a max reducer channel
min_channel
Create a min reducer channel
sum_channel
Create a sum reducer channel