pub struct BinaryOperatorAggregate<T, F>{ /* private fields */ }Expand description
A channel that reduces values using a binary operator.
This channel maintains a single value and applies a reduction function when new values are written. This is useful for operations like summing, finding max/min, or any other associative binary operation.
Example
use rust_langgraph::channels::{BaseChannel, BinaryOperatorAggregate};
// Sum reducer
let mut channel = BinaryOperatorAggregate::new(0, |a, b| a + b);
channel.update(vec![serde_json::json!(1), serde_json::json!(2), serde_json::json!(3)]).unwrap();
assert_eq!(channel.get().unwrap(), Some(serde_json::json!(6)));Implementations