EphemeralValue

Struct EphemeralValue 

pub struct EphemeralValue<T> { /* private fields */ }
A channel that is cleared after each superstep.

Ephemeral channels are useful for temporary data that should only be visible to nodes within a single superstep. After the step completes, the value is automatically cleared.

Example

use rust_langgraph::channels::{BaseChannel, EphemeralValue};

let mut channel = EphemeralValue::<String>::new();
channel.update(vec![serde_json::json!("temporary")]).unwrap();
assert!(channel.get().unwrap().is_some());

// After superstep (simulated by calling clear)
channel.clear();
assert!(channel.get().unwrap().is_none());

Implementations

Source

impl<T> EphemeralValue<T>

pub fn new() -> Self

Create a new empty EphemeralValue channel

pub fn clear(&mut self)

Clear the ephemeral value