pub struct StateSnapshot<S> {
pub state: S,
pub checkpoint: Checkpoint,
pub metadata: CheckpointMetadata,
pub config: Config,
}Expand description
A snapshot of graph state at a specific checkpoint.
This includes both the checkpoint data and the deserialized state.
Fields
state: SThe state at this snapshot
checkpoint: CheckpointThe checkpoint
metadata: CheckpointMetadataMetadata
config: ConfigConfiguration