Module memory

Module memory 

In-memory checkpoint backend.

A simple checkpoint saver that stores checkpoints in memory. Useful for development and testing, but checkpoints are lost when the process exits.

Structs

MemorySaver
In-memory checkpoint storage.