Node abstraction for graph execution.
Nodes are the computational units in a LangGraph. Each node takes state as input and produces updated state as output.
Structs
- Channel
Write - Specification for writing to a channel after node execution
- Pregel
Node - A node in the Pregel execution engine.
Traits
- Node
- The core trait for graph nodes.
Functions
- node_fn
- Helper to create a simple node from an async function
- simple_
node - Helper to create a node that doesn’t use config