pub struct ChannelWrite {
pub channel: String,
pub skip_none: bool,
pub mapper: Option<String>,
}Expand description
Specification for writing to a channel after node execution
Fields
channel: StringThe channel to write to
skip_none: boolWhether to skip writing if the value is None
mapper: Option<String>Optional mapper function name
Implementations
Sourceimpl ChannelWrite
impl ChannelWrite