Module runtime

Module runtime 

Runtime context for node execution.

The Runtime provides nodes with access to execution context like the current step, checkpoint ID, and configuration.

Structs

Runtime
Execution context available to nodes during execution.

Functions

shared_runtime
Create a shared runtime

Type Aliases

SharedRuntime
Shared runtime context that can be passed between tasks