State management and message handling.
This module defines the State trait which is the core abstraction for
graph state, as well as built-in state types like MessagesState for
chat applications.
Structs
- Dict
State - A simple dictionary-based state.
- Message
- A message in a conversation.
- Messages
State - State that contains a list of messages.
- Tool
Call - A tool call in a message.
Traits
- State
- The core trait for graph state.
Functions
- add_
messages - Add messages to an existing list with smart merging.