Binary operator aggregate channel implementation.
A channel that reduces multiple writes using a binary operator function.
Structs
- Binary
Operator Aggregate - A channel that reduces values using a binary operator.
Functions
- max_
channel - Create a max reducer channel
- min_
channel - Create a min reducer channel
- sum_
channel - Create a sum reducer channel