In-memory checkpoint backend.
A simple checkpoint saver that stores checkpoints in memory. Useful for development and testing, but checkpoints are lost when the process exits.
Structs
- Memory
Saver - In-memory checkpoint storage.
In-memory checkpoint backend.
A simple checkpoint saver that stores checkpoints in memory. Useful for development and testing, but checkpoints are lost when the process exits.