Module nodes

Module nodes 

Node abstraction for graph execution.

Nodes are the computational units in a LangGraph. Each node takes state as input and produces updated state as output.

Structs

ChannelWrite
Specification for writing to a channel after node execution
PregelNode
A node in the Pregel execution engine.

Traits

Node
The core trait for graph nodes.

Functions

node_fn
Helper to create a simple node from an async function
simple_node
Helper to create a node that doesn’t use config

Type Aliases

NodeArc
Type alias for arc’d nodes (more efficient for shared ownership)
NodeBox
Type alias for boxed nodes