Module state

Module state 

State management and message handling.

This module defines the State trait which is the core abstraction for graph state, as well as built-in state types like MessagesState for chat applications.

Structs

DictState
A simple dictionary-based state.
Message
A message in a conversation.
MessagesState
State that contains a list of messages.
ToolCall
A tool call in a message.

Traits

State
The core trait for graph state.

Functions

add_messages
Add messages to an existing list with smart merging.