pub struct Send {
pub node: String,
pub arg: Value,
}Expand description
A command to send work to a specific node with custom input.
Send enables dynamic routing where the graph can decide at runtime
to invoke specific nodes with specific inputs, enabling map-reduce patterns.
Example
use rust_langgraph::types::Send;
use serde_json::json;
let send = Send::new("process_item", json!({"item_id": 42}));Fields
node: StringThe name of the node to send to
arg: ValueThe input to send to the node
Implementations